import { View } from "react-native";
import React from "react";
import { act, render } from "@testing-library/react-native";
import { CellWithFocusable } from "../CellWithFocusable";

import { focusManager } from "@applicaster/zapp-react-native-utils/appUtils/focusManager";

const renderWith = (props) => {
  return render(<CellWithFocusable {...props} />);
};

describe("CellWithFocusable", () => {
  it("should render in default state", () => {
    const props = {
      index: 0,
      item: {},
      CellRenderer: View,
      id: "id",
      groupId: "groupId",
      onFocus: jest.fn(),
      scrollTo: jest.fn(),
    };

    const wrapper = renderWith(props);

    expect(wrapper.UNSAFE_getByType("View").props.state).toBe("default");
  });

  it("should render in default state", () => {
    const props = {
      index: 0,
      item: {},
      CellRenderer: View,
      id: "id",
      groupId: "groupId",
      onFocus: jest.fn(),
      scrollTo: jest.fn(),
    };

    focusManager.isGroupItemFocused = jest.fn(() => true);

    const wrapper = renderWith(props);

    expect(wrapper.UNSAFE_getByType("View").props.state).toBe("default");
  });

  it("should render in focused state", () => {
    const props = {
      index: 0,
      item: {},
      CellRenderer: View,
      id: "id",
      groupId: "groupId",
      onFocus: jest.fn(),
      scrollTo: jest.fn(),
    };

    focusManager.isGroupItemFocused = jest.fn(() => true);
    const wrapper = renderWith(props);

    act(() => {
      focusManager.on.mock.calls[focusManager.on.mock.calls.length - 1][1]();
    });

    expect(wrapper.UNSAFE_getByType("View").props.state).toBe("focused");
  });
});
