import * as React from "react";
import { View, StyleSheet } from "react-native";
import * as R from "ramda";

import { ScreenLayoutContext } from "@applicaster/zapp-react-native-ui-components/Contexts/ScreenLayoutContext";
import { useNavigation } from "@applicaster/zapp-react-native-utils/reactHooks/navigation";
import { ifEmptyUseFallback } from "@applicaster/zapp-react-native-utils/cellUtils";
import { useCurrentScreenData } from "@applicaster/zapp-react-native-utils/reactHooks/screen";
import { useTheme } from "@applicaster/zapp-react-native-utils/theme";

import { useScreenConfiguration } from "../../River/useScreenConfiguration";
import { routeIsPlayerScreen } from "@applicaster/zapp-react-native-utils/navigationUtils";

type Props = {
  children: React.ReactNode;
};

function displayFullScreen({ currentRoute, screenData }) {
  const shouldHookBeFullScreen =
    screenData?.hookPlugin?.module?.presentFullScreen;

  return (
    routeIsPlayerScreen(currentRoute) ||
    !!screenData?.general?.present_full_screen ||
    !!shouldHookBeFullScreen
  );
}

const styles = StyleSheet.create({
  container: { flex: 1, height: "100%", width: "100%" },
});

// eslint-disable-next-line react/display-name
export const ScreenContainer = React.memo(function ScreenContainer({
  children,
}: Props) {
  const { screenMarginBottom } = React.useContext(ScreenLayoutContext);
  const { currentRoute, screenData } = useNavigation();
  const screen = useCurrentScreenData();

  const { marginBottom, backgroundColor, paddingTop, paddingBottom } =
    useScreenConfiguration(screen?.id);

  const theme = useTheme();
  const getThemeValue = React.useCallback(R.propOr(0, R.__, theme), [theme]);

  const fullscreen = React.useCallback(
    displayFullScreen({ currentRoute, screenData }),
    [currentRoute, screenData]
  );

  const themeStyles = React.useMemo(
    () =>
      fullscreen
        ? {}
        : {
            marginBottom: ifEmptyUseFallback(marginBottom, screenMarginBottom),
            backgroundColor: ifEmptyUseFallback(backgroundColor, "transparent"),
            paddingTop: ifEmptyUseFallback(
              paddingTop,
              getThemeValue("component_padding_top")
            ),
            paddingBottom: ifEmptyUseFallback(
              paddingBottom,
              getThemeValue("component_padding_bottom")
            ),
          },
    [
      fullscreen,
      screenMarginBottom,
      marginBottom,
      backgroundColor,
      paddingTop,
      paddingBottom,
    ]
  );

  const viewStyles = React.useMemo(
    () => [styles.container, themeStyles],
    [themeStyles]
  );

  return (
    <View testID="screen-container" style={viewStyles}>
      {children}
    </View>
  );
});
