import * as React from "react";
import { View } from "react-native";
import { render } from "@testing-library/react-native";

import { ScreenLayoutContext } from "@applicaster/zapp-react-native-ui-components/Contexts/ScreenLayoutContext";

const navigator_mock = {
  currentRoute: "/river/A1234",
  screenData: {},
};

jest.mock("@applicaster/quick-brick-core/App/ActionSetters", () => ({
  useRiverInitialState: () => ({}),
}));

jest.mock("@applicaster/zapp-react-native-utils/reactHooks/navigation", () => ({
  useNavigation: () => navigator_mock,
}));

jest.mock("../../../River/useScreenConfiguration.ts", () => ({
  useScreenConfiguration: () => ({}),
}));

jest.mock("@applicaster/zapp-react-native-utils/reactHooks/screen", () => ({
  useCurrentScreenData: jest.fn(() => ({})),
}));

jest.mock("@applicaster/zapp-react-native-utils/theme", () => ({
  useTheme: () => ({}),
}));

const { ScreenContainer } = require("../ScreenContainer");

describe("ScreenContainer", () => {
  const screenLayout = {
    screenMarginTop: 10,
    screenMarginBottom: 10,
    screenWidth: 1920,
    screenHeight: 1080,
    componentAnchorPointY: 200,
    componentAvailableWidth: 1920,
  };

  const setScreenLayout = () => {};

  const wrapper = ({ children }) => (
    <ScreenLayoutContext.Provider value={{ ...screenLayout, setScreenLayout }}>
      {children}
    </ScreenLayoutContext.Provider>
  );

  const TestComp = () => <View testID="test-component" />;

  it("renders", () => {
    const { toJSON } = render(
      <ScreenContainer>
        <TestComp />
      </ScreenContainer>,
      { wrapper }
    );

    expect(toJSON()).toMatchSnapshot();
  });

  it("renders passed component", () => {
    const { getByTestId } = render(
      <ScreenContainer>
        <TestComp />
      </ScreenContainer>,
      { wrapper }
    );

    expect(getByTestId("test-component")).toBeDefined();
  });

  it("sets margins provided by the theme", () => {
    const { getByTestId } = render(
      <ScreenContainer>
        <TestComp />
      </ScreenContainer>,
      { wrapper }
    );

    const screen = getByTestId("screen-container");
    expect(screen.props.style).toMatchSnapshot();
  });
});
