import * as React from "react";
import { Image as RnImage, ImageStyle } from "react-native";
import * as R from "ramda";

import { useImageSource } from "./hooks";

type Source = {
  uri: string;
};

type Props = Record<string, any> & {
  style: ImageStyle;
  uri?: string;
  placeholderImage?: string;

  entry?: ZappEntry | ZappFeed;
  withDimensions: (source: Source) => Source;
};

const MemoizedImage = React.memo(RnImage, R.equals);

function Image({
  style,
  uri,
  placeholderImage,
  entry,
  withDimensions,
  ...otherProps
}: Props) {
  const [error, setErrorState] = React.useState(null);

  const source = useImageSource({ uri, entry, otherProps });

  React.useEffect(() => {
    // reset error state on URI change as the error is referencing previous uri
    setErrorState(null);
  }, [uri]);

  const shouldRenderImg = source && !error;

  const defaultPlaceHolderImage = React.useMemo(
    () => ({ uri: placeholderImage || "" }),
    [source, error]
  );

  const _source = shouldRenderImg
    ? withDimensions(source)
    : defaultPlaceHolderImage;

  return (
    // @ts-ignore
    <MemoizedImage
      style={style as ImageStyle}
      onError={() => setErrorState(true)}
      source={_source?.uri ? _source : undefined}
      {...R.omit(["source"], otherProps)}
    />
  );
}

export default Image;
