import { hasElementsSpecificViewType } from "..";

describe("hasElementsSpecificViewType", () => {
  const elementsWithFocusableOneLevelDeep = [
    {
      type: "View",
      elements: [
        {
          type: "View",
        },
        {
          type: "Focusable",
        },
        {
          type: "View",
        },
      ],
    },
  ];

  const elementsWithFocusableTwoLevelDeep = [
    {
      type: "View",
      elements: [
        {
          type: "View",
          elements: [
            {
              type: "View",
            },
            {
              type: "Focusable",
            },
            {
              type: "View",
            },
          ],
        },
      ],
    },
  ];

  const elementsWithoutFocusable = [
    {
      type: "View",
      elements: [
        {
          type: "View",
        },
        {
          type: "View",
        },
      ],
    },
  ];

  it("return true when focusable on 1 level deep", () => {
    const result = hasElementsSpecificViewType("Focusable")(
      elementsWithFocusableOneLevelDeep
    );

    expect(result).toBe(true);
  });

  it("return true when focusable on 2 level deep", () => {
    const result = hasElementsSpecificViewType("Focusable")(
      elementsWithFocusableTwoLevelDeep
    );

    expect(result).toBe(true);
  });

  it("return false when no focusable at all", () => {
    const result = hasElementsSpecificViewType("Focusable")(
      elementsWithoutFocusable
    );

    expect(result).toBe(false);
  });
});
