import React, { useMemo } from "react";
import { View, StyleSheet, LayoutChangeEvent } from "react-native";
import { Title, TitleProps } from "./Title";
import { CloseButton, CloseButtonProps } from "./CloseButton";
import { getCloseButtonProps, getTitleProps } from "./utils";
import { PluginConfiguration } from "../index";

type Props = {
  dismiss: () => void;
  configuration: PluginConfiguration;
  width: number;
  onLayout?: (event: LayoutChangeEvent) => void;
  summary?: string;
  title?: string;
};

const styles = StyleSheet.create({
  container: {
    flexDirection: "row",
    alignItems: "center",
  },
});

export function ModalHeader(props: Props) {
  const { configuration, dismiss, width, onLayout, summary, title } = props;

  const closeButtonProps = useMemo<CloseButtonProps>(
    () => ({
      ...getCloseButtonProps(configuration),
      close: dismiss,
    }),
    [configuration, dismiss]
  );

  const titleProps = useMemo<TitleProps>(
    () => ({
      ...getTitleProps(configuration, "title"),
      text: title,
    }),
    [configuration, title]
  );

  const summaryProps = useMemo<TitleProps>(
    () => ({
      ...getTitleProps(configuration, "summary"),
      text: summary,
    }),
    [configuration, summary]
  );

  const buttonsContainerWidth =
    configuration.modal_bottom_sheet_close_width +
    configuration.modal_bottom_sheet_close_margin_left +
    configuration.modal_bottom_sheet_close_margin_right;

  return (
    <View onLayout={onLayout} style={styles.container}>
      <View
        style={{
          width: width - buttonsContainerWidth,
        }}
      >
        {title && <Title {...titleProps} />}
        {summary && <Title {...summaryProps} />}
      </View>
      <View style={{ width: buttonsContainerWidth }}>
        <CloseButton {...closeButtonProps} />
      </View>
    </View>
  );
}
