import React from "react";
import { Text, Animated } from "react-native";

import { shallow } from "enzyme";
import renderer from "react-test-renderer";

jest.useFakeTimers();

jest.mock("@applicaster/zapp-react-native-redux/hooks", () => ({
  usePickFromState: () => ({
    plugins: [
      {
        name: "offline experience",
        identifier: "offline-experience",
        type: "general",
        module: {
          useOfflineExperienceConfiguration: () => ({
            configurationFields: {},
            localizations: {
              offline_toast_message: "No internet connection",
              online_toast_message: "You are back online",
            },
          }),
        },
      },
    ],
  }),
}));

jest.mock("react-native-safe-area-context", () => ({
  useSafeAreaInsets: () => ({ top: 44 }),
}));

const dismiss = jest.fn();

const {
  NotificationView,
  onlinePhrase,
  offlinePhrase,
} = require("../NotificationView");

describe("NotificationView", () => {
  it("renders", () => {
    shallow(<NotificationView dismiss={dismiss} />);
  });

  it("Show online message when Online", () => {
    const component = renderer.create(
      <NotificationView online dismiss={dismiss} />
    );

    expect(component.root.findByType(Text).props.children).toBe(onlinePhrase);
  });

  it("Show offline message when Online", () => {
    const component = renderer.create(
      <NotificationView online={false} dismiss={dismiss} />
    );

    expect(component.root.findByType(Text).props.children).toBe(offlinePhrase);
  });

  it("When hidden is false to true notification is visible", () => {
    const component = renderer.create(
      <NotificationView online={false} hidden={false} dismiss={dismiss} />
    );

    component.update(
      <NotificationView online={false} hidden={true} dismiss={dismiss} />
    );

    const animatedView = component.root.findByType(Animated.View);
    const animatedViewStyles = animatedView.props.style;

    expect(animatedViewStyles.opacity).toBe(1);
  });
});
