import React from "react";

import renderer, { act } from "react-test-renderer";

jest.useFakeTimers();

let connectionStatus = false;
const previousValue = null;

jest.mock("@applicaster/zapp-react-native-utils/reactHooks/connection", () => {
  return {
    useConnectionInfo: jest.fn(() => connectionStatus),
  };
});

jest.mock("@applicaster/zapp-react-native-utils/reactHooks/utils", () => {
  return {
    usePrevious: jest.fn(() => previousValue),
  };
});

jest.mock("@applicaster/zapp-react-native-redux/hooks", () => ({
  usePickFromState: () => ({
    plugins: [
      {
        name: "offline experience",
        identifier: "offline-experience",
        type: "general",
        module: {
          useOfflineExperienceConfiguration: () => ({
            configurationFields: {},
            localizations: {
              offline_toast_message: "No internet connection",
              online_toast_message: "You are back online",
            },
          }),
        },
      },
    ],
  }),
}));

jest.mock("react-native-safe-area-context", () => ({
  useSafeAreaInsets: () => ({ top: 44 }),
}));

describe("OfflineHandler", () => {
  const { OfflineHandler, NotificationView } = require("../");

  it("renders", () => {
    const instance = renderer.create(<OfflineHandler />);
    expect(instance.toJSON()).toMatchSnapshot();
  });

  it("renders Notification mode if component was rendered while online", () => {
    connectionStatus = true;

    let instance;

    act(() => {
      instance = renderer.create(<OfflineHandler />);
    });

    act(() => {
      instance.update(<OfflineHandler />);
    });

    const notificationsView = instance.root.findByType(NotificationView);
    expect(notificationsView).toBeDefined();
  });
});
