import * as React from "react";
import { isNil } from "ramda";
import { useIsScreenActive } from "@applicaster/zapp-react-native-utils/reactHooks/navigation";
import { usePrevious } from "@applicaster/zapp-react-native-utils/reactHooks/utils";
import { focusManager } from "@applicaster/zapp-react-native-utils/appUtils/focusManager";

export const useRestoreFocus = (): void => {
  const isScreenActive = useIsScreenActive();
  const previousIsScreenActive = usePrevious(isScreenActive);

  React.useEffect(() => {
    if (isNil(previousIsScreenActive)) {
      // it's initial mounting of the screen, do nothing here
      return;
    }

    if (!previousIsScreenActive && isScreenActive) {
      // restore focus when we go back from next screen
      focusManager.setInitialFocus();
    }
  }, [previousIsScreenActive, isScreenActive]);
};
