import * as React from "react";
import { View } from "react-native";
import { act, create } from "react-test-renderer";

const Mocked_RouteManager = jest.fn((props) => (
  <View testID="routeManager" {...props} />
));

const mock_navBarVisibleFlag = true;

const mockIsNavBarVisible = jest.fn(() => mock_navBarVisibleFlag);

const mockIsOrientationCompatible = jest.fn(() => true);

jest.mock("react-native-safe-area-context", () => ({
  useSafeAreaInsets: () => ({ top: 44 }),
}));

jest.mock("../../RouteManager", () => ({
  RouteManager: Mocked_RouteManager,
}));

jest.mock(
  "@applicaster/zapp-react-native-utils/appUtils/orientationHelper",
  () => ({
    isOrientationCompatible: mockIsOrientationCompatible,
    allowedOrientationsForScreen: jest.fn(),
    getOrientation: jest.fn(),
    getScreenOrientation: jest.fn(),
    useGetScreenOrientation: jest.fn(),
    ORIENTATIONS: jest.requireActual(
      "@applicaster/zapp-react-native-utils/appUtils/orientationHelper"
    ).ORIENTATIONS,
  })
);

jest.mock("@applicaster/zapp-react-native-utils/analyticsUtils", () => ({
  useAnalytics: jest.fn(() => ({
    sendScreenEvent: jest.fn(),
  })),
}));

jest.mock("@applicaster/zapp-react-native-utils/theme", () => ({
  useTheme: jest.fn(() => ({
    app_background_color: "blue",
  })),
}));

const NavBar = jest.fn((props) => <View testID="navBar" {...props} />);

jest.mock(
  "@applicaster/zapp-react-native-app/App/Layout/layoutHelpers",
  () => ({
    getNavigationPluginModule: () => NavBar,
  })
);

jest.mock("@applicaster/zapp-react-native-utils/reactHooks/screen", () => ({
  ...(jest.requireActual(
    "@applicaster/zapp-react-native-utils/reactHooks/screen"
  ) as any),
  useScreenData: jest.fn(() => ({
    id: "testId",
    navigations: [{ id: "testId", category: "nav_bar" }],
  })),
  useCurrentScreenData: jest.fn(() => ({
    id: "testId",
  })),
}));

jest.mock("@applicaster/zapp-react-native-utils/reactHooks/navigation", () => ({
  isNavBarVisible: mockIsNavBarVisible,
  useRoute: jest.fn(() => ({
    pathname: "/river/testId",
    screenData: { id: "testId" },
  })),
  useNavigation: jest.fn(() => ({
    canGoBack: () => false,
    currentRoute: "/river/testId",
    activeRiver: { id: "testId" },
    screenData: { id: "testId" },
    data: { screen: { id: "testId" } },
  })),
  useIsScreenActive: jest.fn().mockReturnValue(true),
}));

jest.mock("@applicaster/zapp-react-native-redux/hooks", () => ({
  usePickFromState: () => ({
    plugins: [
      {
        name: "Offline Plugin",
        identifier: "offline-experience",
        type: "general",
        module: {
          OfflineFallbackScreen: ({ children }) => <View>{children}</View>, // eslint-disable-line
        },
      },
    ],
  }),
}));

const {
  ORIENTATIONS,
} = require("@applicaster/zapp-react-native-utils/appUtils/orientationHelper");

const {
  useCurrentScreenData,
} = require("@applicaster/zapp-react-native-utils/reactHooks/screen");

const {
  allowedOrientationsForScreen,
  getOrientation,
  useGetScreenOrientation,
} = require("@applicaster/zapp-react-native-utils/appUtils/orientationHelper");

const navigator = {};
const navBarProps = { nav_items: [] };
const screenData = {};

const screenProps = {
  pathname: "/foo/path",
  navigator,
  navBarProps,
  screenData,
};

const { Screen } = require("..");

describe("<Screen Component />", () => {
  let wrapper;

  beforeEach(() => {
    allowedOrientationsForScreen.mockClear();
    getOrientation.mockClear();
    useGetScreenOrientation.mockClear();
  });

  describe("when the navbar should show", () => {
    act(() => {
      wrapper = create(<Screen {...screenProps} />);
    });

    it("renders correctly", () => {
      expect(wrapper.toJSON()).toMatchSnapshot();
    });
  });

  describe("when the navbar should be hidden", () => {
    beforeEach(() => {
      wrapper = create(<Screen {...screenProps} />);
    });

    it("renders correctly", () => {
      act(() => {
        wrapper = create(<Screen {...screenProps} />);
      });

      expect(wrapper.toJSON()).toMatchSnapshot();
    });
  });

  it("invokes the orientation hook when the route changes", () => {
    act(() => {
      wrapper = create(<Screen {...screenProps} />);
    });

    // @ts-ignore
    useCurrentScreenData.mockReturnValue({
      id: "player-testId",
      general: { screen_orientation: ORIENTATIONS.landscapeSensor },
      plugin_type: "player",
    });

    act(() => {
      wrapper.update(
        <Screen
          {...screenProps}
          pathname="/playable"
          screenData={{
            id: "player-testId",
            general: { screen_orientation: ORIENTATIONS.landscapeSensor },
            plugin_type: "player",
          }}
        />
      );
    });

    useCurrentScreenData.mockReturnValue({
      id: "player-testId",
      general: { screen_orientation: ORIENTATIONS.landscapeSensor },
    });

    act(() => {
      wrapper.update(<Screen {...screenProps} />);
    });

    expect(allowedOrientationsForScreen).toHaveBeenNthCalledWith(
      1,
      ORIENTATIONS.landscapeSensor
    );
  });
});
