import * as React from "react";
import { shallow } from "enzyme";

jest.mock("@applicaster/zapp-react-native-utils/reactHooks/navigation", () => ({
  useRoute: jest.fn(() => ({ screenData: { id: "test" } })),
}));

jest.mock("@applicaster/zapp-react-native-utils/screenState", () => ({
  useScreenState: jest.fn(() => ({
    get: jest.fn(),
    setSelectedEntry: jest.fn(),
  })),
}));

const {
  masterCellBuilder,
} = require("@applicaster/zapp-react-native-ui-components/Components/MasterCell");

const { DefaultCell } = require("../");

describe("DefaultCell", () => {
  it("is a function", () => {
    expect(DefaultCell).toBeFunction();
  });

  it("injects properties from styles into the resulting view trees", () => {
    const styles = {
      tv: {
        main_text: {
          color: "#ff112233", // Take care! #ARGB notation, straight from Zapp's configuration
        },
      },
    } as const;

    const CellRenderer = masterCellBuilder({
      containerStyle: {},
      cellConfiguration: DefaultCell(styles),
    });

    const wrapper = shallow(<CellRenderer />);

    expect(wrapper.find("_Text").first().prop("style").color).toEqual(
      "rgba(239,239,239,1.0)"
    );
  });

  it.skip("matches snapshot", () => {
    // Why snapshots are not compared?
    // Because of the automatic generation of _random_keys in the element mapper:
    // packages/zapp-react-native-ui-components/Components/MasterCell/elementMapper.js
  });
});
