import { create, useStore } from "zustand";
import { produce } from "immer";

type Dimensions = {
  width: Option<number>;
  height: Option<number>;
};

type DimensionsState = {
  dimensions: Record<string, Dimensions>;
  setCachedDimensions: (id: string, dimensions: Dimensions) => void;
};

const dimensionsStore = create<DimensionsState>((set) => ({
  dimensions: {},
  setCachedDimensions: (id, dimensions) =>
    set(
      produce((draft) => {
        draft.dimensions[id] = dimensions;
      })
    ),
}));

const initialDimensions = () => ({
  width: undefined,
  height: undefined,
});

export const useCachedDimensions = (id: string) => {
  const { dimensions, setCachedDimensions } = useStore(
    dimensionsStore
  ) as DimensionsState;

  const getCachedDimensions = () => {
    return dimensions[id] || initialDimensions();
  };

  const handleSetCachedDimensions = (newDimensions) => {
    setCachedDimensions(id, newDimensions);
  };

  return {
    getCachedDimensions,
    setCachedDimensions: handleSetCachedDimensions,
  };
};
