import React from "react";
import * as R from "ramda";
import { View } from "react-native";
import { render } from "@testing-library/react-native";

import {
  entryContext,
  navigator,
  river,
  riverDataSources,
  screenContext,
  screenData,
  searchContext,
} from "./fixtures";

jest.mock("@applicaster/zapp-react-native-utils/reactHooks", () => ({
  useNavigation: jest.fn(() => navigator),
  useRoute: jest.fn(() => ({ screenData })),
}));

jest.mock("../utils", () => ({
  DATASOURCE_CHUNKS: 10,
  loadDatasources: jest.fn(),
  getDatasourceUrl: jest.fn(R.curry((_, component) => component.data.source)),
  usePipesContexts: jest.fn(() => ({
    entryContext,
    searchContext,
    screenContext,
  })),
  ignoreComponentsWithClearCacheFlag: R.reject(
    R.pathEq(["rules", "clear_cache_on_reload"], true)
  ),
}));

const { WithRiverFeedLoader } = require("../index");

const River = function (props) {
  return <View {...props} />;
};

const riverProps = {
  river,
  dispatch: jest.fn(),
};

const DecoratedRiver = WithRiverFeedLoader(River);

const { loadDatasources, getDatasourceUrl } = require("../utils");

describe("WithRiverFeedLoader", () => {
  const getWrapper = () => render(<DecoratedRiver {...riverProps} />);

  beforeEach(() => {
    getDatasourceUrl.mockClear();
    loadDatasources.mockClear();
  });

  it("renders correctly", () => {
    const wrapper = getWrapper();
    expect(wrapper.toJSON()).toMatchSnapshot();
  });

  it("collects the datasources in the screen and loads them", () => {
    getWrapper();

    expect(getDatasourceUrl).toHaveBeenCalledTimes(1);
    expect(loadDatasources).toHaveBeenCalledTimes(1);

    expect(loadDatasources).toHaveBeenNthCalledWith(
      1,
      riverDataSources,
      river.id,
      riverProps.dispatch
    );
  });
});
