import React from "react";
import { shallow } from "enzyme";
import { View } from "react-native";
import { shallowToJson } from "enzyme-to-json";
import * as navigationHooks from "@applicaster/zapp-react-native-utils/reactHooks/navigation";

const rivers = {
  A123: {
    id: "A123",
  },
  B345: {
    id: "B345",
  },
};

jest.doMock("@applicaster/zapp-react-native-redux/hooks", () => ({
  usePickFromState: jest.fn(() => ({ rivers })),
}));

jest.mock("@applicaster/zapp-react-native-utils/reactHooks/layout", () => ({
  useLayoutVersion: jest.fn(() => true),
}));

jest.spyOn(navigationHooks, "usePathname").mockReturnValue("/home");

// mocks useNavigator to return currentRoute: "/home"
jest.mock("@applicaster/zapp-react-native-utils/reactHooks", () => ({
  useNavigation: jest.fn(() => ({ currentRoute: "/home" })),
  useRoute: jest.fn(() => ({ pathname: "/home" })),
}));

const { withRiver } = require("../index");

const TestComponent = jest.fn(() => <View />);

describe("withRiver HoC", () => {
  const WrappedComponent = withRiver(TestComponent);

  const wrapper = shallow(
    <WrappedComponent screenId="A123" rivers={rivers} otherProp="otherProp" />
  );

  it("renders correctly", () => {
    expect(shallowToJson(wrapper)).toMatchSnapshot();
  });

  it("populates the river prop", () => {
    expect(wrapper.find(TestComponent).prop("river")).toEqual(rivers.A123);
  });
});
